# YouTube to Docs

Process YouTube videos into transcripts, summaries, Q&A, infographics, and more.

GitHub
YouTube URL, Video ID, Playlist ID, Channel Handle, or comma-separated Video IDs
Output File
Model Suite
Shortcut to use a specific model suite for everything.
gemini-flash: summarization (gemini-3-flash-preview), TTS (gemini-2.5-flash-preview-tts-Kore), infographic (gemini-3.1-flash-image-preview).
gemini-pro: summarization (gemini-3.1-pro-preview), TTS (gemini-2.5-pro-preview-tts-Kore), infographic (gemini-3-pro-image-preview).
gemini-flash-pro-image: summarization (gemini-3-flash-preview), TTS (gemini-2.5-flash-preview-tts-Kore), infographic (gemini-3-pro-image-preview).
gcp-pro: summarization (gemini-3.1-pro-preview), TTS (gcp-chirp3), infographic (gemini-3-pro-image-preview).
Also sets "Skip YouTube summary".
Summary Model
Transcript Source
Text-To-Speech Model
Infographic Model
Alt Text Model
Translate
Suggest Corrected Captions
Post Process (JSON)
Combine infographic + audio
Skip YouTube summary
Verbose output
Processing...

## Artifacts